@@ -1,5 +1,6 @@
 from .cch_dialog import CchDialog
 from ta_cch_axcess import logger
+import re
 
 
 class Documents(CchDialog):
@@ -43,7 +44,7 @@ class Documents(CchDialog):
                     ("Files" in children.legacy_properties()["Name"])
                     or ("File" in children.legacy_properties()["Name"])
                 ):
-                    files_number = children.legacy_properties()["Name"].replace("Files", "").strip()
+                    files_number = re.sub(r"File|Files", "", children.legacy_properties()["Name"]).strip()
 
             if found_row:
                 break
@@ -51,7 +52,7 @@ class Documents(CchDialog):
             row_counter = row_counter + 1
 
         if row_counter == 1:
-            files_number = 1
+            files_number = "1"
 
         for record in records:
             if "Records" in record.legacy_properties()["Name"]:
